@@ -1,5 +1,8 @@
+use nxui::messagebox::MessageBox;
 use nxui::util::*;
+use nxui::natives_and_messaging::*;
 use nxui::window::demowindow::DemoWindow;
+use nxui::window::Frame;
 
 fn main() {
     let win = DemoWindow::new();
