@@ -1,7 +1,7 @@
 use crate::io::storage::Storage;
 use crate::messagebox::MessageBox;
 use crate::natives_and_messaging::*;
-use crate::window::{Application, Frame, WindowAttributes};
+use crate::window::{Application, Frame, Attributes};
 
 pub struct DemoWindow {
 
@@ -20,8 +20,8 @@ impl Application for DemoWindow {
         "Demo Application".to_string()
     }
 
-    fn attributes(&self) -> WindowAttributes {
-        WindowAttributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100,false)
+    fn attributes(&self) -> Attributes {
+        Attributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100)
     }
 
     fn startup(&self,storage: Storage) {
